@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "py-vterm-interaction" "1.0.9"
+(define-package "py-vterm-interaction" "20251024.2208"
   "A mode for Python REPL using vterm."
   '((emacs  "27.1")
     (vterm  "0.0.2")
